@@ -7,7 +7,7 @@ use Log::Any '$log';
 use LWP::Simple;
 use Parse::Number::ID qw(parse_number_id);
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(get_currencies convert_currency);
@@ -139,7 +139,7 @@ Finance::Currency::Convert::KlikBCA - Convert currencies using data from KlikBCA
 
 =head1 VERSION
 
-version 0.04
+This document describes version 0.05 of Finance::Currency::Convert::KlikBCA (from Perl distribution Finance-Currency-Convert-KlikBCA), released on 2014-05-17.
 
 =head1 SYNOPSIS
 
@@ -176,7 +176,14 @@ No arguments.
 
 Return value:
 
-Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
 
 =head1 TODO
 
